==> srecord-1.38.tar.gz: srecord-1.38/test/01/t0119a.sh <==
#!/bin/sh
#
#       srecord - The "srecord" program.
#       Copyright (C) 2007 Peter Miller
#
#       This program is free software; you can redistribute it and/or modify
#       it under the terms of the GNU General Public License as published by
#       the Free Software Foundation; either version 3 of the License, or
#       (at your option) any later version.
#
#       This program is distributed in the hope that it will be useful,
#       but WITHOUT ANY WARRANTY; without even the implied warranty of
#       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#       GNU General Public License for more details.
#
#       You should have received a copy of the GNU General Public License
#       along with this program. If not, see
#       <http://www.gnu.org/licenses/>.
#
here=`pwd`
if test $? -ne 0 ; then exit 2; fi
work=${TMP_DIR-/tmp}/$$

pass()
{
        cd $here
        rm -rf $work
        echo PASSED
        exit 0
}

fail()
{
        cd $here
        rm -rf $work
        echo 'FAILED test of the output -asm -word-output functionality'
        exit 1
}

no_result()
{
        cd $here
        rm -rf $work
        echo 'NO RESULT for test of the output -asm -word-output functionality'
        exit 2
}

trap "no_result" 1 2 3 15

bin=$here/${1-.}/bin
mkdir $work
if test $? -ne 0; then no_result; fi
cd $work
if test $? -ne 0; then no_result; fi

cat > test.in << 'fubar'
S00600004844521B
S10500000011E9
S107000333445566C3
S10500088899D1
S5030003F9
fubar
if test $? -ne 0; then no_result; fi

cat > test.ok << 'fubar'
; HDR
        DW      0x1100
; To avoid this next ORG directive, use the --fill filter.
        ORG     3
        DW      0x4433,0x6655
        ORG     8
        DW      0x9988
; upper bound = 0x000A
; lower bound = 0x0000
; length =      0x000A
fubar
if test $? -ne 0; then no_result; fi

$bin/srec_cat test.in -o test.out -asm -ow -hex-style > LOG 2>&1
if test $? -ne 0; then cat LOG; fail; fi

diff test.ok test.out
if test $? -ne 0; then fail; fi

#
# The things tested here, worked.
# No other guarantees are made.
#
pass

# vim:ts=8:sw=4:et

==> srecord-1.39.tar.gz: srecord-1.39/test/01/t0119a.sh <==
#!/bin/sh
#
#       srecord - The "srecord" program.
#       Copyright (C) 2007, 2008 Peter Miller
#
#       This program is free software; you can redistribute it and/or modify
#       it under the terms of the GNU General Public License as published by
#       the Free Software Foundation; either version 3 of the License, or
#       (at your option) any later version.
#
#       This program is distributed in the hope that it will be useful,
#       but WITHOUT ANY WARRANTY; without even the implied warranty of
#       MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#       GNU General Public License for more details.
#
#       You should have received a copy of the GNU General Public License
#       along with this program. If not, see
#       <http://www.gnu.org/licenses/>.
#

TEST_SUBJECT="-asm -word-output"
. test_prelude

cat > test.in << 'fubar'
S00600004844521B
S10500000011E9
S107000333445566C3
S10500088899D1
S5030003F9
fubar
if test $? -ne 0; then no_result; fi

cat > test.ok << 'fubar'
; HDR
        DW      0x1100
; To avoid this next ORG directive, use the --fill filter.
        ORG     3
        DW      0x4433,0x6655
        ORG     8
        DW      0x9988
; upper bound = 0x000A
; lower bound = 0x0000
; length =      0x000A
fubar
if test $? -ne 0; then no_result; fi

srec_cat test.in -o test.out -asm -ow -hex-style > LOG 2>&1
if test $? -ne 0; then cat LOG; fail; fi

diff test.ok test.out
if test $? -ne 0; then fail; fi

#
# The things tested here, worked.
# No other guarantees are made.
#
pass

# vim:ts=8:sw=4:et
